@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -260,7 +260,7 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 static gboolean
 is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
 {
-  WebKitDOMHTMLElement *element;
+  WebKitDOMElement *element;
   gboolean ret;
   gchar *id;
 
@@ -270,8 +270,8 @@ is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
   if (!WEBKIT_DOM_IS_HTML_BUTTON_ELEMENT (node))
     goto out;
 
-  element = WEBKIT_DOM_HTML_ELEMENT (node);
-  id = webkit_dom_html_element_get_id (element);
+  element = WEBKIT_DOM_ELEMENT (node);
+  id = webkit_dom_element_get_id (element);
   if (g_strcmp0 (id, "submit_deny_access") != 0)
     goto out;
 
@@ -300,7 +300,7 @@ is_identity_node (GoaOAuth2Provider *provider, WebKitDOMHTMLInputElement *elemen
   if (g_strcmp0 (element_type, "email") != 0)
     goto out;
 
-  id = webkit_dom_html_element_get_id (WEBKIT_DOM_HTML_ELEMENT (element));
+  id = webkit_dom_element_get_id (WEBKIT_DOM_ELEMENT (element));
   if (g_strcmp0 (id, "Email") != 0)
     goto out;
 
@@ -531,38 +531,36 @@ show_account (GoaProvider         *provider,
               GoaClient           *client,
               GoaObject           *object,
               GtkBox              *vbox,
-              GtkGrid             *left,
-              GtkGrid             *right)
+              GtkGrid             *grid,
+              G_GNUC_UNUSED GtkGrid *dummy)
 {
-  /* Chain up */
-  GOA_PROVIDER_CLASS (goa_google_provider_parent_class)->show_account (provider,
-                                                                       client,
-                                                                       object,
-                                                                       vbox,
-                                                                       left,
-                                                                       right);
+  gint row;
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+  row = 0;
+
+  goa_util_add_account_info (grid, row++, object);
+
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    _("Use for"),
                                                    "mail-disabled",
                                                    _("_Mail"));
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    NULL,
                                                    "calendar-disabled",
                                                    _("Cale_ndar"));
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    NULL,
                                                    "contacts-disabled",
                                                    _("_Contacts"));
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    NULL,
                                                    "chat-disabled",
                                                    _("C_hat"));
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (left, right, object,
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    NULL,
                                                    "documents-disabled",
                                                    _("_Documents"));
